# Architecture Decision Records

This directory contains Architecture Decision Records (ADRs) documenting significant architectural decisions made in this project.

## Index

| ADR | Title | Status | Date |
|-----|-------|--------|------|
| [001](001-random-access-data-stores.md) | Random Access Data Stores for Efficient Data Loading | Accepted | 2026-01-22 |

## What is an ADR?

An Architecture Decision Record captures an important architectural decision made along with its context and consequences. ADRs help future maintainers understand why certain decisions were made.

## Template

When adding a new ADR, use this structure:

```markdown
# ADR-XXX: Title

**Date:** YYYY-MM-DD
**Status:** Proposed | Accepted | Deprecated | Superseded

## Context
What is the issue that we're seeing that is motivating this decision?

## Decision
What is the change that we're proposing and/or doing?

## Consequences
What becomes easier or more difficult to do because of this change?
```
